@@ -1,11 +1,11 @@
 """Extensible memoizing collections and decorators."""
 
-import functools
-import warnings
+from __future__ import absolute_import
 
+import functools
+
+from . import keys
 from .cache import Cache
-from .func import lfu_cache, lru_cache, rr_cache, ttl_cache
-from .keys import hashkey, typedkey
 from .lfu import LFUCache
 from .lru import LRUCache
 from .rr import RRCache
@@ -13,14 +13,10 @@ from .ttl import TTLCache
 
 __all__ = (
     'Cache', 'LFUCache', 'LRUCache', 'RRCache', 'TTLCache',
-    'cached', 'cachedmethod', 'hashkey', 'typedkey',
-    # make cachetools.func.* available for backwards compatibility
-    'lfu_cache', 'lru_cache', 'rr_cache', 'ttl_cache',
+    'cached', 'cachedmethod'
 )
 
-__version__ = '1.1.6'
-
-_default = []  # evaluates to False
+__version__ = '3.1.0'
 
 if hasattr(functools.update_wrapper(lambda f: f(), lambda: 42), '__wrapped__'):
     _update_wrapper = functools.update_wrapper
@@ -31,7 +27,7 @@ else:
         return wrapper
 
 
-def cached(cache, key=hashkey, lock=None):
+def cached(cache, key=keys.hashkey, lock=None):
     """Decorator to wrap a function with a memoizing callable that saves
     results in a cache.
 
@@ -72,29 +68,18 @@ def cached(cache, key=hashkey, lock=None):
     return decorator
 
 
-def cachedmethod(cache, key=_default, lock=None, typed=_default):
+def cachedmethod(cache, key=keys.hashkey, lock=None):
     """Decorator to wrap a class or instance method with a memoizing
     callable that saves results in a cache.
 
     """
-    if key is not _default and not callable(key):
-        key, typed = _default, key
-    if typed is not _default:
-        warnings.warn("Passing 'typed' to cachedmethod() is deprecated, "
-                      "use 'key=typedkey' instead", DeprecationWarning, 2)
-
     def decorator(method):
-        # pass method to default key function for backwards compatibilty
-        if key is _default:
-            makekey = functools.partial(typedkey if typed else hashkey, method)
-        else:
-            makekey = key  # custom key function always receive method args
         if lock is None:
             def wrapper(self, *args, **kwargs):
                 c = cache(self)
                 if c is None:
                     return method(self, *args, **kwargs)
-                k = makekey(self, *args, **kwargs)
+                k = key(*args, **kwargs)
                 try:
                     return c[k]
                 except KeyError:
@@ -110,7 +95,7 @@ def cachedmethod(cache, key=_default, lock=None, typed=_default):
                 c = cache(self)
                 if c is None:
                     return method(self, *args, **kwargs)
-                k = makekey(self, *args, **kwargs)
+                k = key(*args, **kwargs)
                 try:
                     with lock(self):
                         return c[k]
@@ -123,13 +108,5 @@ def cachedmethod(cache, key=_default, lock=None, typed=_default):
                 except ValueError:
                     pass  # value too large
                 return v
-        _update_wrapper(wrapper, method)
-
-        # deprecated wrapper attribute
-        def getter(self):
-            warnings.warn('%s.cache is deprecated' % method.__name__,
-                          DeprecationWarning, 2)
-            return cache(self)
-        wrapper.cache = getter
-        return wrapper
+        return _update_wrapper(wrapper, method)
     return decorator
