@@ -1,48 +1,57 @@
 """`functools.lru_cache` compatible memoizing function decorators."""
 
+from __future__ import absolute_import
+
 import collections
 import functools
 import random
-import time
-import warnings
+
+try:
+    from time import monotonic as default_timer
+except ImportError:
+    from time import time as default_timer
 
 try:
     from threading import RLock
-except ImportError:
+except ImportError:  # pragma: no cover
     from dummy_threading import RLock
 
-from .keys import hashkey, typedkey
+from . import keys
+from .lfu import LFUCache
+from .lru import LRUCache
+from .rr import RRCache
+from .ttl import TTLCache
 
 __all__ = ('lfu_cache', 'lru_cache', 'rr_cache', 'ttl_cache')
 
 
-class _NLock:
-    def __enter__(self):
-        pass
-
-    def __exit__(self, *exc):
-        pass
-
 _CacheInfo = collections.namedtuple('CacheInfo', [
     'hits', 'misses', 'maxsize', 'currsize'
 ])
 
-_marker = object()
+
+class _UnboundCache(dict):
+
+    maxsize = None
+
+    @property
+    def currsize(self):
+        return len(self)
 
 
-def _deprecated(message, level=2):
-    warnings.warn('%s is deprecated' % message, DeprecationWarning, level)
+class _UnboundTTLCache(TTLCache):
+    def __init__(self, ttl, timer):
+        TTLCache.__init__(self, float('inf'), ttl, timer)
+
+    @property
+    def maxsize(self):
+        return None
 
 
-def _cache(cache, typed=False, context=_marker):
+def _cache(cache, typed=False):
     def decorator(func):
-        key = typedkey if typed else hashkey
-        if context is _marker:
-            lock = RLock()
-        elif context is None:
-            lock = _NLock()
-        else:
-            lock = context()
+        key = keys.typedkey if typed else keys.hashkey
+        lock = RLock()
         stats = [0, 0]
 
         def cache_info():
@@ -77,57 +86,55 @@ def _cache(cache, typed=False, context=_marker):
             return v
         functools.update_wrapper(wrapper, func)
         if not hasattr(wrapper, '__wrapped__'):
-            wrapper.__wrapped__ = func  # Python < 3.2
+            wrapper.__wrapped__ = func  # Python 2.7
         wrapper.cache_info = cache_info
         wrapper.cache_clear = cache_clear
         return wrapper
     return decorator
 
 
-def lfu_cache(maxsize=128, typed=False, getsizeof=None, lock=_marker):
+def lfu_cache(maxsize=128, typed=False):
     """Decorator to wrap a function with a memoizing callable that saves
     up to `maxsize` results based on a Least Frequently Used (LFU)
     algorithm.
 
     """
-    from .lfu import LFUCache
-    if lock is not _marker:
-        _deprecated("Passing 'lock' to lfu_cache()", 3)
-    return _cache(LFUCache(maxsize, getsizeof), typed, lock)
+    if maxsize is None:
+        return _cache(_UnboundCache(), typed)
+    else:
+        return _cache(LFUCache(maxsize), typed)
 
 
-def lru_cache(maxsize=128, typed=False, getsizeof=None, lock=_marker):
+def lru_cache(maxsize=128, typed=False):
     """Decorator to wrap a function with a memoizing callable that saves
     up to `maxsize` results based on a Least Recently Used (LRU)
     algorithm.
 
     """
-    from .lru import LRUCache
-    if lock is not _marker:
-        _deprecated("Passing 'lock' to lru_cache()", 3)
-    return _cache(LRUCache(maxsize, getsizeof), typed, lock)
+    if maxsize is None:
+        return _cache(_UnboundCache(), typed)
+    else:
+        return _cache(LRUCache(maxsize), typed)
 
 
-def rr_cache(maxsize=128, choice=random.choice, typed=False, getsizeof=None,
-             lock=_marker):
+def rr_cache(maxsize=128, choice=random.choice, typed=False):
     """Decorator to wrap a function with a memoizing callable that saves
     up to `maxsize` results based on a Random Replacement (RR)
     algorithm.
 
     """
-    from .rr import RRCache
-    if lock is not _marker:
-        _deprecated("Passing 'lock' to rr_cache()", 3)
-    return _cache(RRCache(maxsize, choice, getsizeof), typed, lock)
+    if maxsize is None:
+        return _cache(_UnboundCache(), typed)
+    else:
+        return _cache(RRCache(maxsize, choice), typed)
 
 
-def ttl_cache(maxsize=128, ttl=600, timer=time.time, typed=False,
-              getsizeof=None, lock=_marker):
+def ttl_cache(maxsize=128, ttl=600, timer=default_timer, typed=False):
     """Decorator to wrap a function with a memoizing callable that saves
     up to `maxsize` results based on a Least Recently Used (LRU)
     algorithm with a per-item time-to-live (TTL) value.
     """
-    from .ttl import TTLCache
-    if lock is not _marker:
-        _deprecated("Passing 'lock' to ttl_cache()", 3)
-    return _cache(TTLCache(maxsize, ttl, timer, getsizeof), typed, lock)
+    if maxsize is None:
+        return _cache(_UnboundTTLCache(ttl, timer), typed)
+    else:
+        return _cache(TTLCache(maxsize, ttl, timer), typed)
